@@ -4,7 +4,6 @@ package org.virtualbox_6_0.jaxws;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -42,16 +41,13 @@ import javax.xml.bind.annotation.XmlType;
 public class IAdditionsFacility {
 
     @XmlElement(required = true)
-    @XmlSchemaType(name = "string")
     protected AdditionsFacilityClass classType;
     protected long lastUpdated;
     @XmlElement(required = true)
     protected String name;
     @XmlElement(required = true)
-    @XmlSchemaType(name = "string")
     protected AdditionsFacilityStatus status;
     @XmlElement(required = true)
-    @XmlSchemaType(name = "string")
     protected AdditionsFacilityType type;
 
     /**
